@@ -15,8 +15,39 @@
 # specific language governing permissions and limitations
 # under the License.
 
-adbc_allocate_error <- function(shelter = NULL) {
-  .Call(RAdbcAllocateError, shelter)
+
+#' Get extended error information from an array stream
+#'
+#' @param stream A [nanoarrow_array_stream][nanoarrow::as_nanoarrow_array_stream]
+#'
+#' @return `NULL` if stream was not created by a driver that supports
+#'   extended error information or a list whose first element is the
+#'   status code and second element is the `adbc_error` object. The
+#'   `acbc_error` must not be accessed if `stream` is explicitly released.
+#' @export
+#'
+#' @examples
+#' db <- adbc_database_init(adbc_driver_monkey())
+#' con <- adbc_connection_init(db)
+#' stmt <- adbc_statement_init(con, mtcars)
+#' stream <- nanoarrow::nanoarrow_allocate_array_stream()
+#' adbc_statement_execute_query(stmt, stream)
+#' adbc_error_from_array_stream(stream)
+#'
+adbc_error_from_array_stream <- function(stream) {
+  if (!inherits(stream, "nanoarrow_array_stream") || !adbc_xptr_is_valid(stream)) {
+    stop("`stream` must be a valid nanoarrow_array_stream")
+  }
+
+  .Call(RAdbcErrorFromArrayStream, stream)
+}
+
+adbc_allocate_error <- function(shelter = NULL, use_legacy_error = NULL) {
+  if (is.null(use_legacy_error)) {
+    use_legacy_error <- getOption("adbcdrivermanager.use_legacy_error", FALSE)
+  }
+
+  .Call(RAdbcAllocateError, shelter, use_legacy_error)
 }
 
 stop_for_error <- function(status, error) {
@@ -62,12 +93,12 @@ str.adbc_error <- function(object, ...) {
 
 #' @export
 length.adbc_error <- function(x, ...) {
-  3L
+  4L
 }
 
 #' @export
 names.adbc_error <- function(x, ...) {
-  c("message", "vendor_code", "sqlstate")
+  c("message", "vendor_code", "sqlstate", "details")
 }
 
 #' @export
